@@ -623,4 +623,7 @@ program w_base_module_sjpack_test
   call MessageNotify('M','Test of genral function', &
        'Test of general function succeeded!') 
 
+  call MessageNotify('M','w_base_module', &
+       'w_base_module_sjpack functions tests succeeded.') 
+
 end program w_base_module_sjpack_test
